import EventProcessor from "./internal/event/EventProcessor";
import { Decision, Experiment, FeatureFlagDecision, HackleEvent, HackleUser, InAppMessageDecision, MatchValueType, RemoteConfigDecision, VariationKey } from "./internal/model/model";
import WorkspaceFetcher from "./internal/workspace/WorkspaceFetcher";
import { Comparable } from "./internal/util/Comparable";
import ExperimentEvaluator from "./internal/evaluation/evalautor/experiment/ExperimentEvaluator";
import RemoteConfigEvaluator from "./internal/evaluation/evalautor/remoteconfig/RemoteConfigEvaluator";
import { ManualOverrideStorage } from "./internal/evaluation/target/ManualOverrideStorage";
import UserEventFactory from "./internal/event/UserEventFactory";
import { Clock } from "./internal/util/TimeUtil";
import { InAppMessageEvaluator } from "./internal/evaluation/evalautor/iam/InAppMessageEvaluator";
import InAppMessageHiddenStorage from "./internal/evaluation/target/InAppMessageHiddenStorage";
import { InAppMessageImpressionStorage } from "../hackle/iam/storage/InAppMessageImpressionStorage";
/**
 * DO NOT use this class directly.
 * This class is only used internally by Hackle.
 * Backward compatibility is not supported.
 * Please use server-side or client-side HackleClient instead.
 */
export default class HackleCore {
    private readonly experimentEvaluator;
    private readonly remoteConfigEvaluator;
    private readonly inAppMessageEvaluator;
    private readonly workspaceFetcher;
    private readonly eventFactory;
    private readonly eventProcessor;
    private readonly errorDedupDeterminer;
    private readonly clock;
    constructor(experimentEvaluator: ExperimentEvaluator, remoteConfigEvaluator: RemoteConfigEvaluator, inAppMessageEvaluator: InAppMessageEvaluator, workspaceFetcher: WorkspaceFetcher, eventFactory: UserEventFactory, eventProcessor: EventProcessor, errorDedupDeterminer: ErrorDedupDeterminer, clock: Clock);
    static create(workspaceFetcher: WorkspaceFetcher, eventProcessor: EventProcessor, manualOverrideStorages: ManualOverrideStorage[], inAppMessageHiddenStorage: InAppMessageHiddenStorage, inAppMessageImpressionStorage: InAppMessageImpressionStorage): HackleCore;
    getExperiment(experimentKey: number): Experiment | undefined;
    experiment(experimentKey: number, user: HackleUser, defaultVariation: VariationKey): Decision;
    experiments(user: HackleUser): Comparable<Experiment, Decision>;
    private experimentInternal;
    featureFlag(featureKey: number, user: HackleUser): FeatureFlagDecision;
    featureFlags(user: HackleUser): Comparable<Experiment, FeatureFlagDecision>;
    private featureFlagInternal;
    inAppMessage(messageKey: number, user: HackleUser): InAppMessageDecision;
    /**
     * Used in in-app message event trigger determiner
     */
    tryInAppMessage(messageKey: number, user: HackleUser): InAppMessageDecision;
    track(event: HackleEvent, user: HackleUser, timestamp?: number): void;
    trackException(exception: Error, user: HackleUser): void;
    flush(sync?: boolean): void;
    remoteConfig(parameterKey: string, user: HackleUser, requiredType: MatchValueType, defaultValue: string | number | boolean): RemoteConfigDecision;
    close(): void;
}
export declare class ErrorDedupDeterminer {
    private previous?;
    isDedupTarget(error: Error): boolean;
    _isSameError(currentError: Error, previousError?: Error): boolean;
}
