import ConditionMatcher from "./ConditionMatcher";
import Evaluator, { EvaluatorContext, EvaluatorRequest } from "../evalautor/Evaluator";
import { Experiment, TargetCondition } from "../../model/model";
import ValueOperatorMatcher from "./ValueOperatorMatcher";
import ExperimentEvaluation from "../evalautor/experiment/ExperimentEvaluation";
export default class ExperimentConditionMatcher implements ConditionMatcher {
    private readonly abTestMatcher;
    private readonly featureFlagMatcher;
    constructor(abTestMatcher: AbTestConditionMatcher, featureFlagMatcher: FeatureFlagConditionMatcher);
    matches(request: EvaluatorRequest, context: EvaluatorContext, condition: TargetCondition): boolean;
}
declare abstract class ExperimentMatcher {
    protected readonly evaluator: Evaluator;
    protected readonly valueOperatorMatcher: ValueOperatorMatcher;
    protected constructor(evaluator: Evaluator, valueOperatorMatcher: ValueOperatorMatcher);
    matches(request: EvaluatorRequest, context: EvaluatorContext, condition: TargetCondition): boolean;
    private evaluate;
    abstract experiment(request: EvaluatorRequest, key: number): Experiment | undefined;
    abstract resolve(request: EvaluatorRequest, evaluation: ExperimentEvaluation): ExperimentEvaluation;
    abstract evaluationMatches(evaluation: ExperimentEvaluation, condition: TargetCondition): boolean;
}
export declare class AbTestConditionMatcher extends ExperimentMatcher {
    constructor(evaluator: Evaluator, valueOperatorMatcher: ValueOperatorMatcher);
    private static AB_TEST_MATCHED_REASONS;
    experiment(request: EvaluatorRequest, key: number): Experiment | undefined;
    resolve(request: EvaluatorRequest, evaluation: ExperimentEvaluation): ExperimentEvaluation;
    evaluationMatches(evaluation: ExperimentEvaluation, condition: TargetCondition): boolean;
}
export declare class FeatureFlagConditionMatcher extends ExperimentMatcher {
    constructor(evaluator: Evaluator, valueOperatorMatcher: ValueOperatorMatcher);
    experiment(request: EvaluatorRequest, key: number): Experiment | undefined;
    resolve(request: EvaluatorRequest, evaluation: ExperimentEvaluation): ExperimentEvaluation;
    evaluationMatches(evaluation: ExperimentEvaluation, condition: TargetCondition): boolean;
}
export {};
