export interface Transport {
    send(request: TransportRequest): Promise<TransportResponse>;
}
export declare type TransportMethod = "GET" | "POST";
export declare class TransportRequest {
    readonly url: string;
    readonly method: TransportMethod;
    readonly body: string | null;
    readonly headers: TransportHeaders;
    readonly options: TransportOptions;
    constructor(url: string, method: TransportMethod, body: string | null, headers: TransportHeaders, options: TransportOptions);
    static builder(): TransportRequestBuilder;
    static get(url: string): TransportRequest;
    toBuilder(): TransportRequestBuilder;
}
export declare class TransportRequestBuilder {
    private _url;
    private _method;
    private _body;
    private _headers;
    private _timeoutMillis;
    constructor(request?: TransportRequest);
    url(url: string): TransportRequestBuilder;
    method(method: TransportMethod): TransportRequestBuilder;
    body(body: string): TransportRequestBuilder;
    addHeader(name: string, value: string): TransportRequestBuilder;
    timeoutMillis(timeoutMillis: number): TransportRequestBuilder;
    build(): TransportRequest;
}
export declare class TransportResponse {
    readonly statusCode: number;
    readonly body: string | null;
    readonly headers: TransportHeaders;
    constructor(statusCode: number, body: string | null, headers: TransportHeaders);
    static ok(body?: string, headers?: TransportHeaders): TransportResponse;
    static of(statusCode: number, body?: string, headers?: TransportHeaders): TransportResponse;
    isSuccessful(): boolean;
    isClientError(): boolean;
    isNotModified(): boolean;
}
export interface TransportOptions {
    readonly timeoutMillis: number | null;
}
export declare class TransportHeaders {
    private readonly headers;
    constructor(headers: Map<string, string>);
    static empty(): TransportHeaders;
    static builder(): TransportHeadersBuilder;
    get(name: string): string | null;
    getOrDefault(name: string, defaultValue: string): string;
    raw(): Record<string, string>;
    toBuilder(): TransportHeadersBuilder;
    static IF_MODIFIED_SINCE: string;
    static LAST_MODIFIED: string;
    static ACCEPT_ENCODING: string;
}
export declare class TransportHeadersBuilder {
    private readonly headers;
    constructor(headers: Map<string, string>);
    add(name: string, value: string): TransportHeadersBuilder;
    build(): TransportHeaders;
}
