import { InAppMessageHorizontalAlignment, InAppMessageVerticalAlignment, List } from "../model/model";
import { TargetDto } from "./dto";
export interface InAppMessageDto {
    id: number;
    key: number;
    status: string;
    timeUnit: string;
    startEpochTimeMillis: number | null;
    endEpochTimeMillis: number | null;
    eventTriggerRules: List<InAppMessageEventTriggerRuleDto>;
    eventFrequencyCap?: InAppMessageEventFrequencyCapDto;
    targetContext: InAppMessageTargetContextDto;
    messageContext: InAppMessageContextDto;
}
export interface InAppMessageEventTriggerRuleDto {
    eventKey: string;
    targets: List<TargetDto>;
}
export interface InAppMessageEventFrequencyCapDto {
    identifiers: InAppMessageIdentifierCapDto[];
    duration?: InAppMessageDurationCapDto;
}
export interface InAppMessageIdentifierCapDto {
    identifierType: string;
    countPerIdentifier: number;
}
export interface InAppMessageDurationCapDto {
    durationUnit: InAppMessageDurationDto;
    countPerDuration: number;
}
export interface InAppMessageDurationDto {
    timeUnit: string;
    amount: number;
}
export interface InAppMessageTargetContextDto {
    targets: List<TargetDto>;
    overrides: List<InAppMessageTargetRuleOverrideDto>;
}
export interface InAppMessageTargetRuleOverrideDto {
    identifierType: string;
    identifiers: string[];
}
export interface InAppMessageAlignmentDto {
    vertical: InAppMessageVerticalAlignment;
    horizontal: InAppMessageHorizontalAlignment;
}
export interface InAppMessageLayoutDto {
    displayType: string;
    layoutType: string;
    alignment: InAppMessageAlignmentDto | null;
}
export interface InAppMessageContextDto {
    defaultLang: string;
    exposure: InAppMessageExposureDto;
    platformTypes: string[];
    orientations: string[];
    messages: List<InAppMessageContextMessageDto>;
}
export interface InAppMessageExposureDto {
    type: string;
    key: number | null;
}
export interface InAppMessageContextMessageDto {
    variationKey: string | null;
    lang: string;
    layout: InAppMessageLayoutDto;
    images: List<InAppMessageContextImageDto>;
    imageAutoScroll: InAppMessageContextImageAutoScrollDto | null;
    text?: InAppMessageContextTextDto | null;
    closeButton: InAppMessageContextCloseButtonDto | null;
    buttons: List<InAppMessageContextButtonDto>;
    background: InAppMessageContextMessageBackgroundDto;
    action: InAppMessageContextActionDto | null;
    outerButtons: InAppMessagePositionalButtonDto[];
    innerButtons: InAppMessagePositionalButtonDto[];
}
export interface InAppMessageContextImageDto {
    orientation: string;
    imagePath: string;
    action: InAppMessageContextActionDto | null;
}
export interface InAppMessageContextImageAutoScrollDto {
    interval: InAppMessageDurationDto;
}
export interface InAppMessageContextActionDto {
    behavior: string;
    type: string;
    value: string | null;
}
export interface InAppMessageContextTextDto {
    title: InAppMessageContextTextContentDto;
    body: InAppMessageContextTextContentDto;
}
export interface InAppMessageContextTextContentDto {
    text: string;
    style: InAppMessageContextTextContentStyleDto;
}
export interface InAppMessageContextTextContentStyleDto {
    textColor: string;
}
export interface InAppMessageContextCloseButtonDto {
    style: {
        color: string;
    };
    action: InAppMessageContextActionDto;
}
export interface InAppMessageContextButtonDto {
    text: string;
    action: InAppMessageContextActionDto;
    style: InAppMessageContextButtonStyleDto;
}
export interface InAppMessageContextButtonStyleDto {
    textColor: string;
    bgColor: string;
    borderColor: string;
}
export interface InAppMessageContextMessageBackgroundDto {
    color: string;
}
export interface InAppMessagePositionalButtonDto {
    button: InAppMessageContextButtonDto;
    alignment: InAppMessageAlignmentDto;
}
