import { Decision, FeatureFlagDecision, HackleEvent, HackleRemoteConfig, Properties, User, VariationKey } from "../core/internal/model/model";
import { HackleExperiment, HackleInAppMessageListener } from "../public/model";
import { PropertyOperations } from "./property/PropertyOperations";
import { BrowserHackleClient, PageView } from "./index.browser";
import { HackleAppInvocationProcessor } from "./invocator/HackleAppInvocationProcessor";
import { HackleSubscriptionOperations } from "./subscription/HackleSubscriptionOperations";
export interface HackleApp {
    getAppSdkKey: () => string;
    getAppMode?: () => string;
    getInvocationType: () => string;
    invoke?: (stringified: string) => string | null;
}
declare global {
    interface Window {
        _hackleApp?: HackleApp;
    }
}
export declare enum HackleAppMode {
    native = "native",
    web_view_wrapper = "web_view_wrapper"
}
export declare function isHackleWebApp(_window: Window): _window is Window & {
    _hackleApp: HackleApp;
};
export declare class NativeAppHackleClient implements BrowserHackleClient {
    private readonly invocationProcessor;
    constructor(invocationProcessor: HackleAppInvocationProcessor);
    getSessionId(): string;
    getUser(): User;
    setUser(user: User): Promise<void>;
    setUserId(userId: string | number | undefined): Promise<void>;
    setDeviceId(deviceId: string): Promise<void>;
    setUserProperty(key: string, value: any): Promise<void>;
    setUserProperties(properties: Properties<string>): Promise<void>;
    updateUserProperties(operations: PropertyOperations): Promise<void>;
    updatePushSubscriptions(operations: HackleSubscriptionOperations): Promise<void>;
    updateSmsSubscriptions(operations: HackleSubscriptionOperations): Promise<void>;
    updateKakaoSubscriptions(operations: HackleSubscriptionOperations): Promise<void>;
    resetUser(): Promise<void>;
    setPhoneNumber(phoneNumber: string): Promise<void>;
    unsetPhoneNumber(): Promise<void>;
    variation(experimentKey: number, user?: User | string, defaultVariation?: VariationKey): string;
    variationDetail(experimentKey: number, user?: User | string, defaultVariation?: VariationKey): Decision;
    isFeatureOn(featureKey: number, user?: User | string): boolean;
    featureFlagDetail(featureKey: number, user?: User | string): FeatureFlagDecision;
    track(event: HackleEvent | string, user?: User | string): void;
    trackPageView(option?: PageView | undefined): void;
    remoteConfig(user?: string | User | undefined): HackleRemoteConfig;
    onReady(block: () => void, timeout?: number | undefined): void;
    showUserExplorer(): void;
    hideUserExplorer(): void;
    setInAppMessageListener(_listener: HackleInAppMessageListener | null): void;
    fetch(): Promise<void>;
    onInitialized(config?: {
        timeout?: number | undefined;
    } | undefined): Promise<{
        success: boolean;
    }>;
    close(): void;
    getExperiment(experimentKey: number): HackleExperiment | undefined;
    private convertEvent;
    private convertUser;
    private defaultUser;
}
export declare class WebViewHackleClient implements BrowserHackleClient {
    private readonly browser;
    private readonly app;
    constructor(browser: BrowserHackleClient, app: BrowserHackleClient);
    getSessionId(): string;
    getUser(): User;
    syncUser(): Promise<void>;
    setUser(user: User): Promise<void>;
    setUserId(userId: string | number | undefined): Promise<void>;
    setDeviceId(deviceId: string): Promise<void>;
    setUserProperty(key: string, value: any): Promise<void>;
    setUserProperties(properties: Properties<string>): Promise<void>;
    updateUserProperties(operations: PropertyOperations): Promise<void>;
    updatePushSubscriptions(operations: HackleSubscriptionOperations): Promise<void>;
    updateSmsSubscriptions(operations: HackleSubscriptionOperations): Promise<void>;
    updateKakaoSubscriptions(operations: HackleSubscriptionOperations): Promise<void>;
    resetUser(): Promise<void>;
    setPhoneNumber(phoneNumber: string): Promise<void>;
    unsetPhoneNumber(): Promise<void>;
    variation(experimentKey: number, user?: User | string, defaultVariation?: VariationKey): string;
    variationDetail(experimentKey: number, user?: User | string, defaultVariation?: VariationKey): Decision;
    isFeatureOn(featureKey: number, user?: User | string): boolean;
    featureFlagDetail(featureKey: number, user?: User | string): FeatureFlagDecision;
    track(event: HackleEvent | string, user?: User | string): void;
    trackPageView(option?: PageView | undefined): void;
    remoteConfig(user?: string | User | undefined): HackleRemoteConfig;
    onReady(block: () => void, timeout?: number | undefined): void;
    showUserExplorer(): void;
    hideUserExplorer(): void;
    fetch(): Promise<void>;
    onInitialized(config?: {
        timeout?: number | undefined;
    } | undefined): Promise<{
        success: boolean;
    }>;
    close(): void;
    setInAppMessageListener(listener: HackleInAppMessageListener | null): void;
    getExperiment(experimentKey: number): HackleExperiment | undefined;
}
