import { InAppMessageActionEvent, InAppMessageCloseEvent, InAppMessageEvent, InAppMessageImpressionEvent } from "./InAppMessageEvent";
import { InAppMessageView } from "../view/InAppMessageView";
import { InAppMessageImpressionStorage } from "../../storage/InAppMessageImpressionStorage";
import { InAppMessageActionHandlerFactory } from "./InAppMessageActionHandler";
export interface InAppMessageEventProcessor<Event extends InAppMessageEvent> {
    supports(event: InAppMessageEvent): boolean;
    process(view: InAppMessageView, event: Event, timestamp: number): void;
}
export declare class InAppMessageEventProcessorFactory {
    private readonly processors;
    constructor(processors: InAppMessageEventProcessor<InAppMessageEvent>[]);
    get(event: InAppMessageEvent): InAppMessageEventProcessor<InAppMessageEvent> | undefined;
}
export declare class InAppMessageImpressionEventProcessor implements InAppMessageEventProcessor<InAppMessageImpressionEvent> {
    private readonly impressionStorage;
    private static IMPRESSION_MAX_SIZE;
    constructor(impressionStorage: InAppMessageImpressionStorage);
    process(view: InAppMessageView, event: InAppMessageImpressionEvent, timestamp: number): void;
    private saveImpression;
    supports(event: InAppMessageEvent): boolean;
}
export declare class InAppMessageCloseEventProcessor implements InAppMessageEventProcessor<InAppMessageCloseEvent> {
    process(view: InAppMessageView, event: InAppMessageCloseEvent, timestamp: number): void;
    supports(event: InAppMessageEvent): boolean;
}
export declare class InAppMessageActionEventProcessor implements InAppMessageEventProcessor<InAppMessageActionEvent> {
    private readonly actionHandlerFactory;
    constructor(actionHandlerFactory: InAppMessageActionHandlerFactory);
    process(view: InAppMessageView, event: InAppMessageActionEvent, timestamp: number): void;
    supports(event: InAppMessageEvent): boolean;
}
